@@ -177,7 +177,7 @@ class CodeBlock(TextElement):
     ) -> RenderResult:
         code = str(self.text).rstrip()
         syntax = Panel(
-            Syntax(code, self.lexer_name, theme=self.theme),
+            Syntax(code, self.lexer_name, theme=self.theme, word_wrap=True),
             border_style="dim",
             box=box.SQUARE,
         )
@@ -399,7 +399,7 @@ class Markdown(JupyterMixin):
         style (Union[str, Style], optional): Optional style to apply to markdown.
         hyperlinks (bool, optional): Enable hyperlinks. Defaults to ``True``.
         inline_code_lexer: (str, optional): Lexer to use if inline code highlighting is
-            enabled. Defaults to "python".
+            enabled. Defaults to None.
         inline_code_theme: (Optional[str], optional): Pygments theme for inline code
             highlighting, or None for no highlighting. Defaults to None.
     """
